@@ -55,7 +55,8 @@ KGVPart::KGVPart( QWidget* parentWidget, const char*,
     _mimetypeScanner( 0 ),
     _isGuiInitialized( false ),
     _isDocumentOpen( false ),
-    _isFileDirty( false )
+    _isFileDirty( false ),
+    _currentPage( 0 )
 {
     setInstance( KGVFactory::instance() );
 
@@ -457,6 +458,7 @@ bool KGVPart::openURL( const KURL& url )
 	return false;
 
     m_url = url;
+    _currentPage = 0;
 
     emit setWindowCaption( m_url.prettyURL() );
 
@@ -525,7 +527,7 @@ void KGVPart::slotOpenFileCompleted()
     else	
     {
 	_isDocumentOpen = true;
-	_docManager->firstPage();
+	_docManager->goToPage( _currentPage );
 	stateChanged( "documentState" );
 	connect( _pageView, SIGNAL( nextPage() ), SLOT( slotNextPage() ));
 	connect( _pageView, SIGNAL( prevPage() ), SLOT( slotPrevPage() ));
@@ -605,6 +607,7 @@ void KGVPart::slotFileDirty( const QString& fileName )
 void KGVPart::slotNewPage( int )
 {
     updatePageDepActions();
+    _currentPage = _docManager->currentPage();
     //media->setCurrentItem (miniWidget()->getSize()-1);
     //orientation->setCurrentItem (miniWidget()->getOrientation()-1);
     //TODO -- zoom
