@@ -69,6 +69,12 @@ public:
      */
     virtual bool closeURL();
 
+    /**
+     * Sets the current page that will be selected in slotOpenFileCompleted().
+     * Useful for to restore the current page during session restoring.
+     */
+    void setCurrentPage( int page ) { _currentPage = page; }
+
     static KAboutData* createAboutData();
 
 public slots:
