@@ -123,7 +123,7 @@ KGVShell::readProperties( KConfig *config )
     KURL url = config->readEntry( "URL" );
     if ( url.isValid() ) {
         openURL( url );
-        m_gvpart->miniWidget()->goToPage( config->readNumEntry( "Current Page", 0 ));
+        m_gvpart->setCurrentPage( config->readNumEntry("Current Page", 0 ));
         // m_gvpart->miniWidget()->setMagstep( config->readNumEntry( "Magnification", 1 ));
     }
 }
