@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: filewidget.cpp,v 1.10 2002/03/23 12:47:35 pfeiffer Exp $
+** $Id: filewidget.cpp,v 1.10.2.2 2002/07/17 15:02:00 pfeiffer Exp $
 **
 ** Created : 98
 **
@@ -20,7 +20,6 @@
 #include "filefinder.h"
 #include "filewidget.h"
 #include "kuickdata.h"
-#include "kuickio.h"
 #include "kuickshow.h"
 
 #ifdef KeyPress
@@ -67,7 +66,7 @@ void FileWidget::initActions()
 {
     int index = 0;
     KActionCollection *coll = actionCollection();
-    KActionSeparator *sep = new KActionSeparator( coll );
+    KActionSeparator *sep = new KActionSeparator( coll, "kuicksep" );
     KActionMenu *menu = static_cast<KActionMenu*>( coll->action("popupMenu") );
 
     menu->insert( coll->action("kuick_showInOtherWindow"), index++ );
@@ -102,7 +101,7 @@ void FileWidget::reloadConfiguration()
     }
 }
 
-bool FileWidget::hasFiles() const 
+bool FileWidget::hasFiles() const
 {
     return (numFiles() > 0);
 }
@@ -156,17 +155,15 @@ bool FileWidget::eventFilter( QObject *o, QEvent *e )
 	
 	if ( (k->state() & (ControlButton | AltButton)) == 0 ) {
 	    int key = k->key();
-	    if ( key == Key_Space && !KuickShow::s_viewers.isEmpty() ) {
-		topLevelWidget()->hide();
-                k->accept();
-		return true;
-	    }
-	    else if ( key == Key_Delete ) {
+ 	    if ( actionCollection()->action("delete")->shortcut().contains( key ) ) 
+            {
                 k->accept();
 		KFileItem *item = getCurrentItem( false );
-		if ( item )
-		    KuickIO::self( this )->deleteFile( item->url(),
-						    k->state() & ShiftButton );
+		if ( item ) {
+                    KFileItemList list;
+                    list.append( item );
+		    del( list, (k->state() & ShiftButton) == 0 );
+                }
 		return true;
 	    }
 	
