@@ -1,5 +1,5 @@
 /***************************************************************************
-** $Id: imagewindow.cpp,v 1.15.2.2 2002/05/07 23:43:48 pfeiffer Exp $
+** $Id: imagewindow.cpp,v 1.15.2.3 2002/07/17 15:02:00 pfeiffer Exp $
 **
 ** ImageWindow: extends the simple  ImlibWidget to display image in a Qt window
 **		can zoom and scroll images inside the QWidget
@@ -31,6 +31,7 @@
 #include <qdragobject.h>
 
 #include <kaccel.h>
+#include <kapplication.h>
 #include <kconfig.h>
 #include <kcursor.h>
 #include <kdebug.h>
@@ -246,7 +247,7 @@ void ImageWindow::updateGeometry( int imWidth, int imHeight )
     caption = caption.arg( kuim->filename() ).
               arg( kuim->originalWidth() ).
               arg( kuim->originalHeight() );
-    setCaption( caption );
+    setCaption( kapp->makeStdCaption( caption ));
 }
 
 
