@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: kuickio.h,v 1.1.1.1 2001/08/16 21:31:24 pfeiffer Exp $
+** $Id: kuickio.h,v 1.1.1.1.2.2 2002/07/05 13:57:27 pfeiffer Exp $
 **
 ** Definition of something or other
 **
@@ -25,12 +25,6 @@ class KuickIO : public QObject
 public:
     static KuickIO * self( QWidget *parent );
 
-    bool deleteFile( const KURL&, bool dontAsk );
-    bool deleteFiles( const KURL::List&, bool dontAsk );
-
-signals:
-    void deleted( const KURL& );
-
 private:
     static QWidget * s_parent;
     static KuickIO * s_self;
