@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: kuickshow.cpp,v 1.22.2.2 2002/04/19 00:30:45 pfeiffer Exp $
+** $Id: kuickshow.cpp,v 1.22.2.5 2002/07/18 16:13:08 pfeiffer Exp $
 **
 ** KuickShow - a fast and comfortable image viewer based on Rasterman's Imlib
 **
 ** Created : 98
 **
-** Copyright (C) 1998-2001 by Carsten Pfeiffer.  All rights reserved.
+** Copyright (C) 1998-2002 by Carsten Pfeiffer.  All rights reserved.
 **
 ****************************************************************************/
 
@@ -201,7 +201,7 @@ void KuickShow::initGUI( const KURL& startDir )
     coll->action("reload")->plug( tBar );
 
     tBar->insertSeparator();
-    
+
     coll->action( "short view" )->plug( tBar );
     coll->action( "detailed view" )->plug( tBar );
     coll->action( "preview")->plug( tBar );
@@ -263,7 +263,6 @@ void KuickShow::viewerDeleted()
 void KuickShow::slotHighlighted( const KFileItem *fi )
 {
     QString size;
-    //size.sprintf( " %.1f kb", (float) fi->size()/1024 );
     size = i18n("%1 kb").arg(KGlobal::locale()->formatNumber((float)fi->size()/1024, 1));
     statusBar()->changeItem( size, SIZE_ITEM );
     statusBar()->changeItem( fi->url().prettyURL(), URL_ITEM );
@@ -523,68 +522,78 @@ bool KuickShow::eventFilter( QObject *o, QEvent *e )
 	if ( k ) { // keypress
 	    ret = true;
 	    int key = k->key();
-	
+            
 	    // Key_Shift shouldn't load the browser in nobrowser mode, it
 	    // is used for zooming in the imagewindow
-	    if ( !fileWidget && key != Key_Escape && key != Key_Shift ) {
-		KURL start;
-		QFileInfo fi( m_viewer->filename() );
-		start.setPath( fi.dirPath( true ) );
-		initGUI( start );
+	    if ( !fileWidget )
+            {
+                if ( key != Key_Escape && key != Key_Shift ) 
+                {
+                    KURL start;
+                    QFileInfo fi( m_viewer->filename() );
+                    start.setPath( fi.dirPath( true ) );
+                    initGUI( start );
 
-		// the fileBrowser will list the start-directory asynchronously
-		// so we can't immediately continue. There is no current-item
-		// and no next-item (actually no item at all). So we tell the
-		// browser the initial current-item and wait for it to tell us
-		// when it's ready. Then we will replay this KeyEvent.
-		fileWidget->setInitialItem( fi.fileName() );
-		delayedRepeatEvent( m_viewer, k );
-		connect( fileWidget, SIGNAL( finished() ),
-			 SLOT( slotReplayEvent() ));
-		return true;
+                    // the fileBrowser will list the start-directory 
+                    // asynchronously so we can't immediately continue. There 
+                    // is no current-item and no next-item (actually no item 
+                    // at all). So we tell the browser the initial 
+                    // current-item and wait for it to tell us when it's ready.
+                    // Then we will replay this KeyEvent.
+                    fileWidget->setInitialItem( fi.fileName() );
+                    delayedRepeatEvent( m_viewer, k );
+                    connect( fileWidget, SIGNAL( finished() ),
+                             SLOT( slotReplayEvent() ));
+                    return true;
+                }
+                
+                return KMainWindow::eventFilter( o, e );
 	    }
 
+            // we definitely have a filewidget here!
+            
  	    // FIXME: make all this stuff via KStdAccel and KAccel ->slots
 
-	    switch( key ) {
-	    case Key_Home: {
+            KKey kkey( key );
+            if ( KStdAccel::home().contains( kkey ) )
+            {
 		item = fileWidget->gotoFirstImage();
 		item_next = fileWidget->getNext( false );
-		break;
 	    }
 
-	    case Key_End: {
+            else if ( KStdAccel::end().contains( kkey ) )
+            {
 		item = fileWidget->gotoLastImage();
 		item_next = fileWidget->getPrevious( false );
-		break;
 	    }
 
-	    case Key_Enter:
-		item = fileWidget->getCurrentItem( true );
-		break;
-
-	    case Key_Delete: {
+            else if ( fileWidget->actionCollection()->action("delete")->shortcut().contains( key ))
+            {
 		KFileItem *cur = fileWidget->getCurrentItem( false );
 		item = fileWidget->getNext( false ); // don't move
 		if ( !item )
 		    item = fileWidget->getPrevious( false );
-		
-		if ( KuickIO::self(m_viewer)->deleteFile( m_viewer->filename(),
-                                                    k->state() & ShiftButton) )
-		    fileWidget->setCurrentItem( item );
-		else
-		    item = cur; // restore old current item
-		break;
+
+                KFileItem it( KFileItem::Unknown, KFileItem::Unknown,
+                                m_viewer->url() );
+                KFileItemList list;
+                list.append( &it );
+                if ( fileWidget->del(list, window,
+                                     (k->state() & ShiftButton) == 0) == 0L )
+                    return true; // aborted deletion
+
+                // ### check failure asynchronously and restore old item?
+                fileWidget->setCurrentItem( item );
 	    }
 
-	    case Key_Space: {
+            else if ( key == Key_Space )
+            {
                 toggleBrowser( !haveBrowser() );
 		return true; // don't pass keyEvent
 	    }
 
-	    default:
+            else
 		ret = false;
-	    }
 
 
 	    if ( FileWidget::isImage( item ) ) {
@@ -807,7 +816,7 @@ void KuickShow::slotReplayEvent()
 
     eventFilter( e->viewer, e->event );
     delete e;
-    
+
     // ### WORKAROUND for QIconView bug in Qt <= 3.0.3 at least
     if ( fileWidget && fileWidget->view() ) {
         QWidget *widget = fileWidget->view()->widget();
@@ -830,6 +839,8 @@ void KuickShow::slotReplayAdvance()
     m_delayedRepeatItem = 0L; // otherwise, eventFilter aborts
 
     // ### WORKAROUND for QIconView bug in Qt <= 3.0.3 at least
+    // Sigh. According to qt-bugs, they won't fix this bug ever. So you can't
+    // rely on sorting to be correct before the QIconView has been show()n.
     if ( fileWidget && fileWidget->view() ) {
         QWidget *widget = fileWidget->view()->widget();
         if ( widget->inherits( "QIconView" ) || widget->child(0, "QIconView" ) ){
