@@ -416,12 +416,12 @@ void ImageListDialog::restoreProperties( KConfig *cfg )
   }
   if( cfg->hasKey( "ListWinPos" ) )
   {
-    move( cfg->readPointEntry( "ListWinPos" ) );   
+    move( cfg->readPointEntry( "ListWinPos" ) );
   }
   if ( cfg->readBoolEntry( "ListVisible", false ) )
   {
     show();
-  }           
+  }
 }
 
 void ImageListDialog::slot_save()
@@ -438,7 +438,7 @@ void ImageListDialog::slot_save()
     KTempFile ktempf;
     tempfile = ktempf.name();
   }
-  
+
   //save file right here
   QFile file( tempfile );
   if( file.open( IO_WriteOnly ) )
@@ -448,15 +448,16 @@ void ImageListDialog::slot_save()
 
     t << "[KView Image List]" << endl;
     (void)m_imagelist.first();
-    do
+    while ( m_imagelist.current() )
     {
       t << m_imagelist.current()->url.url() << endl;
-    } while( m_imagelist.next() != 0 );
+      m_imagelist.next();
+    }
 
     file.close();
 
     (void)m_imagelist.first();
-    for( int i = 0; i < oldposition; i++ ) 
+    for( int i = 0; i < oldposition; i++ )
       (void)m_imagelist.next();
 
     KIO::NetAccess::upload( tempfile, url );
