@@ -23,12 +23,6 @@
 #include "kviewshell.moc"
 
 
-#define StatusBar_ID_PageSize 1
-
-//TODO -- use the statusbar
-//TODO -- don't stay open when no file, go directly to KFileDialog
-
-
 KViewShell::KViewShell(QString partname, KAboutData *about)
   : KParts::MainWindow(), _partname(partname)
 {
@@ -68,8 +62,6 @@ KViewShell::KViewShell(QString partname, KAboutData *about)
   checkActions();
 
   setAcceptDrops(true);
-
-  statusBar()->insertItem("A4",StatusBar_ID_PageSize);
 }
 
 
