@@ -71,12 +71,12 @@ int main(int argc, char **argv)
     KURL url(args->url(1));
     
     if (args->url(1).isMalformed()) {
-      kdError() << QString(I18N_NOOP("The URL %1 is not well-formed.")).arg(args->arg(1)) << endl;
+      kdError(4300) << QString(I18N_NOOP("The URL %1 is not well-formed.")).arg(args->arg(1)) << endl;
       return -1;
     }
     
     if (!args->url(1).isLocalFile()) {
-      kdError() << QString(I18N_NOOP("The URL %1 does not point to a local file. You can only specify local "
+      kdError(4300) << QString(I18N_NOOP("The URL %1 does not point to a local file. You can only specify local "
 			     "files if you are using the '--unique' option.")).arg(args->arg(1)) << endl;
       return -1;
     }
@@ -94,20 +94,20 @@ int main(int argc, char **argv)
 	QDataStream arg(data, IO_WriteOnly);
 	bool result;
 	arg << qualPath.stripWhiteSpace();
-	if (!app.dcopClient()->call("kviewshell", "kmultipage", "is_file_loaded(QString)", data, replyType, replyData))
-	  kdError() << "There was an error using DCOP." << endl;
+	if (!app.dcopClient()->call(*it, "kmultipage", "is_file_loaded(QString)", data, replyType, replyData))
+	  kdError(4300) << "There was an error using DCOP." << endl;
 	else {
 	  QDataStream reply(replyData, IO_ReadOnly);
 	  if (replyType == "bool") {
 	    reply >> result;
 	    if (result == true) {
-	      if (app.dcopClient()->send("kviewshell", "kmultipage", "jumpToReference(QString)", args->url(1).ref()) == true) {
+	      if (app.dcopClient()->send(*it, "kmultipage", "jumpToReference(QString)", args->url(1).ref()) == true) {
 		app.dcopClient()->detach();
 		return 0;
 	      }
 	    }
 	  } else
-	    kdError() << "The DCOP function 'doIt' returned an unexpected type of reply!";
+	    kdError(4300) << "The DCOP function 'doIt' returned an unexpected type of reply!";
 	}
       }
     } 
